const fz = require('zigbee-herdsman-converters/converters/fromZigbee');
const tz = require('zigbee-herdsman-converters/converters/toZigbee');
const exposes = require('zigbee-herdsman-converters/lib/exposes');
const modernExtend = require('zigbee-herdsman-converters/lib/modernExtend');
const e = exposes.presets;
const ea = exposes.access;
const tuya = require('zigbee-herdsman-converters/lib/tuya');
const reporting = require('zigbee-herdsman-converters/lib/reporting');

const definition = {
     fingerprint: [
         {
            modelID: 'TS0601',
            manufacturerName: '_TZE204_5bvfljra',
        },
    ],
    model: 'ERC2102-Z',
    vendor: 'BOX',
    description: 'ERC2102-Z Rail dual controller',
    fromZigbee: [tuya.fz.datapoints, fz.on_off],
    toZigbee: [tuya.tz.datapoints, tz.on_off],

    configure: async (device, coordinatorEndpoint) => {
        await tuya.configureMagicPacket(device, coordinatorEndpoint);
    },

    exposes: [
        e.switch().withEndpoint("l1").setAccess("state", ea.STATE_SET),
        e.switch().withEndpoint("l2").setAccess("state", ea.STATE_SET),
    ],

    meta: {
        multiEndpoint: true,
        tuyaDatapoints: [

                [1, 'state_l1', tuya.valueConverter.onOff], // send and report, bool
                [2, 'state_l2', tuya.valueConverter.onOff], // send and report, bool
                [14, 'relay_status', tuya.valueConverter.raw], // enum: Enum Value: off, on, memory
                [19, 'switch_inching', tuya.valueConverter.raw], // string: #1 control (bit0 - switch, bit7 - bit1 - channel number) / #2 week / #3 #4 start time (min) / #5 #6 end time (min)
        ],
    },
};

module.exports = definition;

